==> zio-aws-storagegateway_2.12-5.17.115.1-sources.jar: zio/aws/storagegateway/model/UpdateBandwidthRateLimitResponse.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.GatewayARN
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateBandwidthRateLimitResponse(
    gatewayARN: Option[GatewayARN] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.UpdateBandwidthRateLimitResponse = {
    import UpdateBandwidthRateLimitResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.UpdateBandwidthRateLimitResponse
      .builder()
      .optionallyWith(
        gatewayARN.map(value => GatewayARN.unwrap(value): java.lang.String)
      )(_.gatewayARN)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.UpdateBandwidthRateLimitResponse.ReadOnly =
    zio.aws.storagegateway.model.UpdateBandwidthRateLimitResponse
      .wrap(buildAwsValue())
}
object UpdateBandwidthRateLimitResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.UpdateBandwidthRateLimitResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.storagegateway.model.UpdateBandwidthRateLimitResponse =
      zio.aws.storagegateway.model
        .UpdateBandwidthRateLimitResponse(gatewayARN.map(value => value))
    def gatewayARN: Option[GatewayARN]
    def getGatewayARN: ZIO[Any, AwsError, GatewayARN] =
      AwsError.unwrapOptionField("gatewayARN", gatewayARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.UpdateBandwidthRateLimitResponse
  ) extends zio.aws.storagegateway.model.UpdateBandwidthRateLimitResponse.ReadOnly {
    override val gatewayARN: Option[GatewayARN] = scala
      .Option(impl.gatewayARN())
      .map(value => zio.aws.storagegateway.model.primitives.GatewayARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.UpdateBandwidthRateLimitResponse
  ): zio.aws.storagegateway.model.UpdateBandwidthRateLimitResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-storagegateway_2.12-5.17.178.1-sources.jar: zio/aws/storagegateway/model/UpdateBandwidthRateLimitResponse.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.GatewayARN
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateBandwidthRateLimitResponse(
    gatewayARN: Optional[GatewayARN] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.UpdateBandwidthRateLimitResponse = {
    import UpdateBandwidthRateLimitResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.UpdateBandwidthRateLimitResponse
      .builder()
      .optionallyWith(
        gatewayARN.map(value => GatewayARN.unwrap(value): java.lang.String)
      )(_.gatewayARN)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.UpdateBandwidthRateLimitResponse.ReadOnly =
    zio.aws.storagegateway.model.UpdateBandwidthRateLimitResponse
      .wrap(buildAwsValue())
}
object UpdateBandwidthRateLimitResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.UpdateBandwidthRateLimitResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.storagegateway.model.UpdateBandwidthRateLimitResponse =
      zio.aws.storagegateway.model
        .UpdateBandwidthRateLimitResponse(gatewayARN.map(value => value))
    def gatewayARN: Optional[GatewayARN]
    def getGatewayARN: ZIO[Any, AwsError, GatewayARN] =
      AwsError.unwrapOptionField("gatewayARN", gatewayARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.UpdateBandwidthRateLimitResponse
  ) extends zio.aws.storagegateway.model.UpdateBandwidthRateLimitResponse.ReadOnly {
    override val gatewayARN: Optional[GatewayARN] = zio.aws.core.internal
      .optionalFromNullable(impl.gatewayARN())
      .map(value => zio.aws.storagegateway.model.primitives.GatewayARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.UpdateBandwidthRateLimitResponse
  ): zio.aws.storagegateway.model.UpdateBandwidthRateLimitResponse.ReadOnly =
    new Wrapper(impl)
}
